<?php

App::uses('AppHelper', 'View/Helper');
App::uses('BasketLib', 'EvBasket.Lib');

class BasketHelper extends AppHelper {

	/**
	 * given the basket item array row
	 * return the text to show on the basket
	 *
	 * @param 	array 	$BasketItem 	The basket item row from the DB
	 * @return 	string
	 */
	public function getItemName($BasketItem) {
		return BasketLib::getItemName($BasketItem);
	}

	/**
	 * helper to just generate the bakset item id and quantity field
	 * keep the template neater
	 *
	 * @param 	array 	$BasketItem 	The basket item row from the DB
	 * @param 	array 	$options 		Form Options array for the quantity - to override class and such
	 * @return 	string
	 */
	public function quantityField($BasketItem, $options = array()) {
		echo $this->_View->Form->addField(
			$BasketItem['id'] . '.BasketItem.id',
			array(
				'type' => 'hidden',
				'value' => $BasketItem['id']
			)
		);

		echo $this->_View->Form->addField(
			$BasketItem['id'] . '.BasketItem.model',
			array(
				'type' => 'hidden',
				'value' => $BasketItem['model']
			)
		);

		echo $this->_View->Form->addField(
			$BasketItem['id'] . '.BasketItem.model_id',
			array(
				'type' => 'hidden',
				'value' => $BasketItem['model_id']
			)
		);

		$options = array_merge(
			array(
				'type' => 'integer',
				'value' => $BasketItem['quantity'],
				'label' => false
			),
			$options
		);

		echo $this->_View->Form->addField(
			$BasketItem['id'] . '.BasketItem.quantity',
			$options
		);
	}

	/**
	 * helper for a delete item link
	 * keeps the template neater
	 *
	 * @param 	array 	$BasketItem 	The basket item row from the DB
	 * @param 	string  $linkText 		The text for the link
	 * @param 	array 	$linkOptions 	Options to be passed to Html->link()
	 * @return 	string
	 */
	public function deleteLink($BasketItem, $linkText, $linkOptions = array()) {
		$route = $this->_View->Route->getItemRoute('EvBasket', 'Basket');
		$route['action'] = 'remove';
		$route[] = $BasketItem['id'];

		$options = array_merge(
			array(
				'confirm' => 'Are you sure?'
			),
			$linkOptions
		);

		echo $this->_View->Html->link(
			$linkText,
			$route,
			$options
		);
	}

	/**
	 * helper to return the basket form update url
	 *
	 * @return string
	 */
	public function getFormUrl($type) {
		$route = $this->_View->Route->getItemRoute('EvBasket', 'Basket');
		$route['action'] = $type;

		return $route;
	}

	/**
	 * Get the totals for the basket and adjust the displayed values depending on if VAT is to be shown or not (config setting)
	 * @param  Object $basket  The basket object containing the current totals and items in the basket.
	 * @param  bool   $showTax An override to display prices including VAT or display tax separately
	 * @return array           An array containing the basket totals with any modification applied.
	 */
	public function getViewTotals($basket, $showTax = false) {
		$allTotals = $basket['BasketTotal'];

		$includeTax = Configure::read('EvBasket.siteIncludingTax');

		if ($includeTax != null && $includeTax || $showTax) {
			//Need to get the original tax amount
			$originalTaxTotal = 0;
			foreach ($basket['BasketItem'] as $basketItem) {
				$originalTaxTotal += $basketItem['row_tax_amount'];
			}

			$totalIds = Hash::combine($allTotals, '{n}.name', '{n}.id');

			$taxAmount = $allTotals[$totalIds[Configure::read('EvBasket.labels.tax')]]['amount'];
			$subTotalAmount = $allTotals[$totalIds[Configure::read('EvBasket.labels.subtotal')]]['amount'];
			$discountAmount = $allTotals[$totalIds[Configure::read('EvBasket.labels.discount')]]['amount'];

			//Get the total price of the basket not including discounts
			$subTotalAmount += $originalTaxTotal;
			$allTotals[$totalIds[Configure::read('EvBasket.labels.subtotal')]]['amount'] = $subTotalAmount;

			//Need to work out the original discount
			if (!empty($discountAmount)) {
				//Work out the difference between the original tax and the discounted tax
				$discountedTaxAmount = $originalTaxTotal - $taxAmount;
				$discountAmount -= $discountedTaxAmount;
				$allTotals[$totalIds[Configure::read('EvBasket.labels.discount')]]['amount'] = $discountAmount;
			}

			//Unset the tax as we now don't want to display it
			unset($allTotals[$totalIds[Configure::read('EvBasket.labels.tax')]]);
		}

		return $allTotals;
	}
}
